

; modified/tested by Paul Sherman
; FU_watermark.scm
; version 2.7 [gimphelp.org]
; 05/05/2012 on GIMP-2.8

; MrQ: 23/01/2022 update for Gimp-2.10/2.99.8; add SF-TEXT, SF-COLOR, offset
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;(gimp-image-get-width image)
; ------------------------------------------------------------------
; Original information ---------------------------------------------
;
; Write a watermark in a corner of the image
; script by Doug Reynolds
;
; End original information ------------------------------------------
;--------------------------------------------------------------------
(cond ((not (defined? 'gimp-image-get-width)) (define gimp-image-get-width gimp-image-width)))
(cond ((not (defined? 'gimp-image-get-height)) (define gimp-image-get-height gimp-image-height)))

(define (text-watermark-on-corner image drawable text font pixsize color location opacity offsetx offsety keep-layers)

	(gimp-image-undo-group-start image)

	(let*
	;Save the foreground color
    ((old-fg (car (gimp-context-get-foreground))))

	;Set the foreground color to white
     (gimp-context-set-foreground color)

  (let*
  	
	;Set the X and Y locations offset by 10 pixels from the chosen corner
     ((imagewid (car (gimp-image-get-width image)))
    	  (imagehgt (car (gimp-image-get-height image)))
    	  (ytext
        	 (cond ((<= location 1) (- (- imagehgt pixsize) offsety))
            	   ((>= location 2) offsety)))
    	  (textwid (car (gimp-text-get-extents-fontname text pixsize 0 font)))
    	  (xtext
        	 (cond ((= (fmod location 2) 0) offsetx)
            	   ((= (fmod location 2) 1) (- (- imagewid textwid) offsetx))))

		;Create a layer with the watermark text
    	(tlayer (car (gimp-text-fontname image -1 xtext ytext text -1 TRUE pixsize 0 font)))
	)

	;Bump map the watermark layer
    (plug-in-bump-map 1 image tlayer tlayer 135 45 3 0 0 0 0 1 0 0)
	
	;Set the opacity of the watermark layer
    (gimp-layer-set-opacity tlayer opacity)
	
	; Merge watermark layer with bottom layer
	 (if (= keep-layers FALSE)                            
        (gimp-image-merge-down image tlayer 2) 
     )

    )

	;Restore the old foreground color
    (gimp-context-set-foreground old-fg)
  )

	;Finish the undo group for the process
    (gimp-image-undo-group-end image) 
    
	;Update the display
	(gimp-displays-flush)
)

(script-fu-register "text-watermark-on-corner"
	"Text Watermark on corner..."
	"Watermark on corner of your choice.\nNice transparent emboss effect.\n\nAlso allows choice of font, size and opacity."
	"Doug Reynolds"
	"GPL"
	"2001/22"
	"RGB*, GRAY*"
	SF-IMAGE "Input Image" 0
	SF-DRAWABLE "Input Drawable" 0
	SF-TEXT "Text" "© gimpscripts.net"
	SF-FONT "Font" "Arial"
	SF-ADJUSTMENT "Size (pixels)" '(30 0 1000 1 10 0 1)
	SF-COLOR "Text Color" '(255 255 255)
	SF-OPTION "Location" '("Lower left" "Lower right" "Upper left" "Upper right")
	SF-ADJUSTMENT "Opacity" '(80 0 100 1 10 0 1)
	SF-ADJUSTMENT "OffsetX" '(10 0 5000 1 10 0 1)
	SF-ADJUSTMENT "OffsetY" '(10 0 5000 1 10 0 1)	
	SF-TOGGLE     "Keep the Layers"   FALSE
)
(script-fu-menu-register "text-watermark-on-corner" "<Image>/Filters/Watermark/")